@@ -1,7 +1,7 @@
 package App::lcpan::Call;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.06'; # VERSION
+our $DATE = '2016-02-14'; # DATE
+our $VERSION = '0.07'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,7 +33,6 @@ _
             default => [],
         },
     },
-    result_naked => 1,
 };
 sub call_lcpan_script {
     require Perinci::CmdLine::Call;
@@ -53,20 +52,19 @@ sub call_lcpan_script {
             unless $res->[0] == 200;
         my $stats = $res->[2];
         my $max_age = $args{max_age} // $ENV{LCPAN_MAX_AGE} // 14*86400;
-        my $max_age_in_days = sprintf("%f", $max_age / 86400);
-        if ((time - $stats->{raw_last_index_time}) > $max_age) {
-            die "lcpan index is over $max_age_in_days day(s) old, ".
-                "please refresh it first with 'lcpan update'\n";
+        my $max_age_in_days = sprintf("%g", $max_age / 86400);
+        my $age = time - $stats->{raw_last_index_time};
+        my $age_in_days = sprintf("%g", $age / 86400);
+        if ($age > $max_age) {
+            die "lcpan index is over $max_age_in_days day(s) old ".
+                "($age_in_days), please refresh it first with 'lcpan update'\n";
         }
     }
 
-    my $res = Perinci::CmdLine::Call::call_cli_script(
+    Perinci::CmdLine::Call::call_cli_script(
         script => 'lcpan',
         argv   => $args{'argv'},
     );
-    die "Can't 'lcpan ".join(" ", @{ $args{argv} || [] })."': $res->[0] - $res->[1]\n"
-        unless $res->[0] == 200;
-    $res->[2];
 }
 
 1;
@@ -84,12 +82,12 @@ App::lcpan::Call - "Call" lcpan script
 
 =head1 VERSION
 
-This document describes version 0.06 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-01-05.
+This document describes version 0.07 of App::lcpan::Call (from Perl distribution App-lcpan-Call), released on 2016-02-14.
 
 =head1 FUNCTIONS
 
 
-=head2 call_lcpan_script(%args) -> any
+=head2 call_lcpan_script(%args) -> [status, msg, result, meta]
 
 "Call" lcpan script.
 
@@ -110,6 +108,15 @@ also undefined, will default to 14 days.
 
 =back
 
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
 Return value:  (any)
 
 =head1 HOMEPAGE
